<?php

use CRM_TwingleCampaign_ExtensionUtil as E;
require_once E::path() . '/CRM/TwingleCampaign/Utils/CaseTypes.php';

return [
  "campaign_types" => [
    "twingle_project" => [
      "name" => "twingle_project",
      "label" => "Twingle Project"
    ],
    "twingle_event" => [
      "name" => "twingle_event",
      "label" => "Twingle Event"
    ],
    "twingle_campaign" => [
      "name" => "twingle_campaign",
      "label" => "Twingle Campaign"
    ]
  ],
  "custom_groups" => [
    "twingle_project_information" => [
      "title" => E::ts("Twingle Information"),
      "name" => "Twingle_Project_Information",
      "extends" => "Campaign",
      "campaign_type" => "twingle_project",
      "weight" => "1"
    ],
    "twingle_project_options" => [
      "title" => E::ts("Twingle Settings"),
      "name" => "Twingle_Project_Options",
      "extends" => "Campaign",
      "campaign_type" => "twingle_project",
      "weight" => "2"
    ],
    "twingle_project_payment_methods" => [
      "title" => E::ts("Twingle Payment Methods"),
      "name" => "Twingle_Project_Payment_Methods",
      "extends" => "Campaign",
      "campaign_type" => "twingle_project",
      "weight" => "3"
    ],
    "twingle_project_embed_codes" => [
      "title" => E::ts("Twingle Embed Codes"),
      "name" => "Twingle_Project_Embed_Codes",
      "extends" => "Campaign",
      "campaign_type" => "twingle_project",
      "collapse_display" => "1",
      "weight" => "4"
    ],
    "twingle_event_information" => [
      "title" => E::ts("Twingle Event Information"),
      "name" => "Twingle_Event_Information",
      "extends" => "Campaign",
      "campaign_type" => "twingle_event"
    ],
    "twingle_campaign_information" => [
      "title" => E::ts("Twingle Campaign Information"),
      "name" => "Twingle_Campaign_Information",
      "extends" => "Campaign",
      "campaign_type" => "twingle_campaign"
    ]
  ],
  "custom_fields" => [
    "twingle_project_id" => [
      "custom_group_id" => "Twingle_Project_Information",
      "label" => E::ts("Twingle Project ID"),
      "name" => "twingle_project_id",
      "is_required" => FALSE,
      "is_searchable" => 1,
      "data_type" => "String",
      "html_type" => "Text",
      "text_length" => 16,
      "is_active" => 1,
      "is_view" => 1,
      "weight" => 1
    ],
    "twingle_project_organisation_id" => [
      "custom_group_id" => "Twingle_Project_Information",
      "label" => E::ts("Organisation ID"),
      "name" => "twingle_project_organisation_id",
      "is_required" => FALSE,
      "is_searchable" => 1,
      "data_type" => "String",
      "html_type" => "Text",
      "text_length" => 32,
      "is_active" => 1,
      "is_view" => 1,
      "weight" => 6
    ],
    "twingle_project_identifier" => [
      "custom_group_id" => "Twingle_Project_Information",
      "label" => E::ts("identifier"),
      "name" => "twingle_project_identifier",
      "is_required" => FALSE,
      "is_searchable" => 1,
      "data_type" => "String",
      "html_type" => "Text",
      "text_length" => 15,
      "is_active" => 1,
      "is_view" => 1,
      "weight" => 3,
      "help_post" => E::ts("An unique identifier for a project (auto generated)")
    ],
    "twingle_project_type" => [
      "custom_group_id" => "Twingle_Project_Information",
      "label" => E::ts("Type"),
      "name" => "twingle_project_type",
      "is_required" => FALSE,
      "is_searchable" => 1,
      "data_type" => "String",
      "html_type" => "Select",
      "option_values" => [
        "default" => E::ts("Default"),
        "event" => E::ts("Events"),
        "membership" => E::ts("Membership"),
        "shop" => E::ts("Shop"),
        "giftshop" => E::ts("Gift Shop")
      ],
      "text_length" => 32,
      "is_active" => 1,
      "is_view" => FALSE,
      "weight" => 2,
      "help_post" => E::ts("Choose the project type. Allow users to create own events or to pay a membership fee."),
      "default_value" => "default"
    ],
    "twingle_project_case" => [
      "custom_group_id" => "Twingle_Project_Information",
      "label" => E::ts("Case"),
      "name" => "twingle_project_case",
      "is_required" => FALSE,
      "is_searchable" => 1,
      "data_type" => "String",
      "html_type" => "Select",
      "option_values" => getCaseTypes(),
      "text_length" => 32,
      "is_active" => 1,
      "is_view" => FALSE,
      "weight" => 3,
      "help_post" => E::ts("Which case should get opened for event creators?")
    ],
    "twingle_project_allow_more" => [
      "custom_group_id" => "Twingle_Project_Information",
      "label" => E::ts("allow more"),
      "name" => "twingle_project_allow_more",
      "is_required" => FALSE,
      "is_searchable" => 1,
      "data_type" => "Boolean",
      "html_type" => "Radio",
      "text_length" => 4,
      "is_active" => 1,
      "is_view" => FALSE,
      "weight" => 4,
      "help_post" => E::ts("Allow to donate more than is defined in the target")
    ],
    "twingle_project_transaction_type" => [
      "custom_group_id" => "Twingle_Project_Information",
      "label" => E::ts("transaction type"),
      "name" => "twingle_project_transaction_type",
      "is_required" => FALSE,
      "is_searchable" => 1,
      "data_type" => "String",
      "html_type" => "Text",
      "text_length" => 32,
      "is_active" => 1,
      "is_view" => FALSE,
      "weight" => 5
    ],
    "twingle_project_url" => [
      "custom_group_id" => "Twingle_Project_Information",
      "label" => E::ts("URL"),
      "name" => "twingle_project_url",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "Memo",
      "html_type" => "TextArea",
      "text_length" => 600,
      "is_active" => 1,
      "is_view" => FALSE,
      "weight" => 6
    ],
    "twingle_project_widget" => [
      "custom_group_id" => "Twingle_Project_Embed_Codes",
      "label" => E::ts("Widget"),
      "name" => "twingle_project_widget",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "Memo",
      "html_type" => "TextArea",
      "text_length" => 600,
      "is_active" => 1,
      "is_view" => 1,
      "weight" => 1
    ],
    "twingle_project_form" => [
      "custom_group_id" => "Twingle_Project_Embed_Codes",
      "label" => E::ts("Form"),
      "name" => "twingle_project_form",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "Memo",
      "html_type" => "TextArea",
      "text_length" => 600,
      "is_active" => 1,
      "is_view" => 1,
      "weight" => 2
    ],
    "twingle_project_widget-single" => [
      "custom_group_id" => "Twingle_Project_Embed_Codes",
      "label" => E::ts("Widget Single"),
      "name" => "twingle_project_widget-single",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "Memo",
      "html_type" => "TextArea",
      "text_length" => 600,
      "is_active" => 1,
      "is_view" => 1,
      "weight" => 3
    ],
    "twingle_project_form-single" => [
      "custom_group_id" => "Twingle_Project_Embed_Codes",
      "label" => E::ts("Form Single"),
      "name" => "twingle_project_form-single",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "Memo",
      "html_type" => "TextArea",
      "text_length" => 600,
      "is_active" => 1,
      "is_view" => 1,
      "weight" => 4
    ],
    "twingle_project_eventall" => [
      "custom_group_id" => "Twingle_Project_Embed_Codes",
      "label" => E::ts("All Events"),
      "name" => "twingle_project_eventall",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "Memo",
      "html_type" => "TextArea",
      "text_length" => 1300,
      "is_active" => 1,
      "is_view" => 1,
      "weight" => 5
    ],
    "twingle_project_eventlist" => [
      "custom_group_id" => "Twingle_Project_Embed_Codes",
      "label" => E::ts("Event List"),
      "name" => "twingle_project_eventlist",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "Memo",
      "html_type" => "TextArea",
      "text_length" => 1300,
      "is_active" => 1,
      "is_view" => 1,
      "weight" => 6
    ],
    "twingle_project_counter" => [
      "custom_group_id" => "Twingle_Project_Embed_Codes",
      "label" => E::ts("Counter"),
      "name" => "twingle_project_counter",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "Memo",
      "html_type" => "TextArea",
      "text_length" => 120,
      "is_active" => 1,
      "is_view" => 1,
      "weight" => 7
    ],
    "twingle_project_page" => [
      "custom_group_id" => "Twingle_Project_Embed_Codes",
      "label" => E::ts("Page"),
      "name" => "twingle_project_page",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "Memo",
      "html_type" => "TextArea",
      "text_length" => 600,
      "is_active" => 1,
      "is_view" => 1,
      "weight" => 8
    ],
    "twingle_project_has_confirmation_mail" => [
      "custom_group_id" => "Twingle_Project_Options",
      "label" => E::ts("Confirmation Mail"),
      "name" => "twingle_project_has_confirmation_mail",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "Boolean",
      "html_type" => "Radio",
      "text_length" => 6,
      "is_active" => 1,
      "is_view" => FALSE,
      "weight" => 1,
      "help_post" => E::ts("Send confirmation mail")
    ],
    "twingle_project_has_donation_receipt" => [
      "custom_group_id" => "Twingle_Project_Options",
      "label" => E::ts("Donation Receipt"),
      "name" => "twingle_project_has_donation_receipt",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "Boolean",
      "html_type" => "Radio",
      "text_length" => 6,
      "is_active" => 1,
      "is_view" => FALSE,
      "weight" => 3,
      "help_post" => E::ts("Offer donation receipts")
    ],
    "twingle_project_has_contact_data" => [
      "custom_group_id" => "Twingle_Project_Options",
      "label" => E::ts("Contact Data"),
      "name" => "twingle_project_has_contact_data",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "Boolean",
      "html_type" => "Radio",
      "text_length" => 6,
      "is_active" => 1,
      "is_view" => FALSE,
      "weight" => 4
    ],
    "twingle_project_donation_rhythm" => [
      "custom_group_id" => "Twingle_Project_Options",
      "label" => E::ts("Donation Rhythm"),
      "name" => "twingle_project_donation_rhythm",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "String",
      "html_type" => "Multi-Select",
      "option_values" => [
        "yearly" => E::ts("yearly"),
        "halfyearly" => E::ts("halfyearly"),
        "quarterly" => E::ts("quarterly"),
        "monthly" => E::ts("monthly"),
        "one_time" => E::ts("one time")
      ],
      "text_length" => 64,
      "is_active" => 1,
      "is_view" => FALSE,
      "weight" => 5,
      "help_post" => E::ts("The selected options are available for selection in the donation widget.")
    ],
    "twingle_project_default_rhythm" => [
      "custom_group_id" => "Twingle_Project_Options",
      "label" => E::ts("Default Rhythm"),
      "name" => "twingle_project_default_rhythm",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "String",
      "html_type" => "Radio",
      "option_values" => [
        "yearly" => E::ts("yearly"),
        "halfyearly" => E::ts("halfyearly"),
        "quarterly" => E::ts("quarterly"),
        "monthly" => E::ts("monthly"),
        "one_time" => E::ts("one time")
      ],
      "text_length" => 64,
      "is_active" => 1,
      "is_view" => FALSE,
      "weight" => 6,
      "help_post" => E::ts("Which donation rhythm should be displayed as selected by default?")
    ],
    "twingle_project_has_newsletter_registration" => [
      "custom_group_id" => "Twingle_Project_Options",
      "label" => E::ts("Newsletter Registration"),
      "name" => "twingle_project_has_newsletter_registration",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "Boolean",
      "html_type" => "Radio",
      "text_length" => 6,
      "is_active" => 1,
      "is_view" => FALSE,
      "weight" => 7,
      "help_post" => E::ts("Enable newsletter registration")
    ],
    "twingle_project_has_postinfo_registration" => [
      "custom_group_id" => "Twingle_Project_Options",
      "label" => E::ts("Postinfo Registration"),
      "name" => "twingle_project_has_postinfo_registration",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "Boolean",
      "html_type" => "Radio",
      "text_length" => 6,
      "is_active" => 1,
      "is_view" => FALSE,
      "weight" => 8,
      "help_post" => E::ts("Enable post info registration")
    ],
    "twingle_project_design_background_color" => [
      "custom_group_id" => "Twingle_Project_Options",
      "label" => E::ts("Background Color"),
      "name" => "twingle_project_design_background_color",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "String",
      "html_type" => "Text",
      "text_length" => 6,
      "is_active" => 1,
      "is_view" => FALSE,
      "weight" => 9,
      "help_post" => E::ts("Hex color code (e.g. ffffff for white)")
    ],
    "twingle_project_design_primary_color" => [
      "custom_group_id" => "Twingle_Project_Options",
      "label" => E::ts("Primary Color"),
      "name" => "twingle_project_design_primary_color",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "String",
      "html_type" => "Text",
      "text_length" => 6,
      "is_active" => 1,
      "is_view" => FALSE,
      "weight" => 10,
      "help_post" => E::ts("Hex color code (e.g. ffffff for white)")
    ],
    "twingle_project_design_font_color" => [
      "custom_group_id" => "Twingle_Project_Options",
      "label" => E::ts("Font Color"),
      "name" => "twingle_project_design_font_color",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "String",
      "html_type" => "Text",
      "text_length" => 6,
      "is_active" => 1,
      "is_view" => FALSE,
      "weight" => 12,
      "help_post" => E::ts("Hex color code (e.g. ffffff for white)")
    ],
    "twingle_project_bcc_email_address" => [
      "custom_group_id" => "Twingle_Project_Options",
      "label" => E::ts("BCC Email"),
      "name" => "twingle_project_bcc_email_address",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "String",
      "html_type" => "Text",
      "text_length" => 64,
      "is_active" => 1,
      "is_view" => FALSE,
      "weight" => 16,
      "help_post" => E::ts("Email address used as bcc addresses for confirmation mail which is send to an user")
    ],
    "twingle_project_donation_value_min" => [
      "custom_group_id" => "Twingle_Project_Options",
      "label" => E::ts("Donation Min"),
      "name" => "twingle_project_donation_value_min",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "String",
      "html_type" => "Text",
      "text_length" => 10,
      "is_active" => 1,
      "is_view" => FALSE,
      "weight" => 17,
      "help_post" => E::ts("Minimum donation value"),
      "default_value" => "5"
    ],
    "twingle_project_donation_value_max" => [
      "custom_group_id" => "Twingle_Project_Options",
      "label" => E::ts("Donation Max"),
      "name" => "twingle_project_donation_value_max",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "String",
      "html_type" => "Text",
      "text_length" => 10,
      "is_active" => 1,
      "is_view" => FALSE,
      "weight" => 18,
      "help_post" => E::ts("Maximum donation value"),
      "default_value" => "500"
    ],
    "twingle_project_donation_value_default" => [
      "custom_group_id" => "Twingle_Project_Options",
      "label" => E::ts("Donation Default"),
      "name" => "twingle_project_donation_value_default",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "String",
      "html_type" => "Text",
      "text_length" => 10,
      "is_active" => 1,
      "is_view" => FALSE,
      "weight" => 19,
      "help_post" => E::ts("Default donation value"),
      "default_value" => "50"
    ],
    "twingle_project_contact_fields" => [
      "custom_group_id" => "Twingle_Project_Options",
      "label" => E::ts("Contact Fields"),
      "name" => "twingle_project_contact_fields",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "String",
      "html_type" => "Multi-Select",
      "option_values" => [
        "salutation" => E::ts("Salutation"),
        "firstname" => E::ts("First name"),
        "lastname" => E::ts("Last name"),
        "company" => E::ts("Company"),
        "birthday" => E::ts("Birthday"),
        "street" => E::ts("Street"),
        "postal_code" => E::ts("Postal Code"),
        "city" => E::ts("City"),
        "country" => E::ts("Country"),
        "telephone" => E::ts("Telephone")
      ],
      "is_active" => 1,
      "is_view" => FALSE,
      "weight" => 20,
      "help_post" => E::ts("Fields to include in contact form")
    ],
    "twingle_project_mandatory_contact_fields" => [
      "custom_group_id" => "Twingle_Project_Options",
      "label" => E::ts("Mandatory Contact Fields"),
      "name" => "twingle_project_mandatory_contact_fields",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "String",
      "html_type" => "Multi-Select",
      "option_values" => [
        "salutation" => E::ts("Salutation"),
        "firstname" => E::ts("First name"),
        "lastname" => E::ts("Last name"),
        "company" => E::ts("Company"),
        "birthday" => E::ts("Birthday"),
        "street" => E::ts("Street"),
        "postal_code" => E::ts("Postal Code"),
        "city" => E::ts("City"),
        "country" => E::ts("Country"),
        "telephone" => E::ts("Telephone")
      ],
      "is_active" => 1,
      "is_view" => FALSE,
      "weight" => 20,
      "help_post" => E::ts("Fields that must get filled in the contact form.")
    ],
    "twingle_project_custom_css" => [
      "custom_group_id" => "Twingle_Project_Options",
      "label" => E::ts("Custom CSS"),
      "name" => "twingle_project_custom_css",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "String",
      "html_type" => "Text",
      "text_length" => 120,
      "is_active" => 1,
      "is_view" => FALSE,
      "weight" => 21,
      "help_post" => E::ts("URL to a custom CSS file that will be included in the frontend")
    ],
    "twingle_project_share_url" => [
      "custom_group_id" => "Twingle_Project_Options",
      "label" => E::ts("Share URL"),
      "name" => "twingle_project_share_url",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "String",
      "html_type" => "Text",
      "text_length" => 120,
      "is_active" => 1,
      "is_view" => FALSE,
      "weight" => 22,
      "help_post" => E::ts("URL for the sharing component on the last page and doi page")
    ],
    "twingle_project_has_contact_mandatory" => [
      "custom_group_id" => "Twingle_Project_Options",
      "label" => E::ts("Contact Mandatory"),
      "name" => "twingle_project_has_contact_mandatory",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "Boolean",
      "html_type" => "Radio",
      "is_active" => 1,
      "is_view" => FALSE,
      "weight" => 23,
      "help_post" => E::ts("If the contact data should be requested mandatory as second step")
    ],
    "twingle_project_has_doi" => [
      "custom_group_id" => "Twingle_Project_Options",
      "label" => E::ts("Double Opt-In"),
      "name" => "twingle_project_has_doi",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "Boolean",
      "html_type" => "Radio",
      "is_active" => 1,
      "is_view" => FALSE,
      "weight" => 24,
      "help_post" => E::ts("Enable Twingle's double opt-in (Do not enable, if you use CiviCRM's double opt-in!)")
    ],
    "twingle_project_has_force_donation_target_buttons" => [
      "custom_group_id" => "Twingle_Project_Options",
      "label" => E::ts("Force Donation Taget as Button"),
      "name" => "twingle_project_has_force_donation_target_buttons",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "Boolean",
      "html_type" => "Radio",
      "is_active" => 1,
      "is_view" => FALSE,
      "weight" => 26,
      "help_post" => E::ts("Force showing the donation targets as buttons")
    ],
    "twingle_project_slidericon" => [
      "custom_group_id" => "Twingle_Project_Options",
      "label" => E::ts("Slider Icon"),
      "name" => "twingle_project_slidericon",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "String",
      "html_type" => "Select",
      "option_values" => [
        "heart" => E::ts("Heart"),
        "asterisk" => E::ts("Asterisk"),
        "animal" => E::ts("Animal"),
        "Rettungsring" => E::ts("Lifebelt"),
        "angellist" => E::ts("Angellist"),
        "handshake" => E::ts("Handshake"),
        "dollar" => E::ts("Dollar"),
        "menue_burger_fine" => E::ts("Menue"),
        "office" => E::ts("Office"),
        "leaf" => E::ts("Leaf"),
        "cog" => E::ts("Cog"),
        "wvg" => E::ts("SVG"),
        "euro" => E::ts("Euro"),
        "stats-dots" => E::ts("Stats"),
        "circle_fine" => E::ts("Circle"),
        "waterdrop_outline" => E::ts("Water drop outline"),
        "waterdrop" => E::ts("Water drop"),
        "gift" => E::ts("Gift"),
        "biene_b" => E::ts("Bee"),
        "blume" => E::ts("Flower"),
        "train" => E::ts("Train"),
        "empty" => E::ts("No Icon")
      ],
      "is_active" => 1,
      "is_view" => FALSE,
      "weight" => 29
    ],
    "twingle_project_has_hidden_logo" => [
      "custom_group_id" => "Twingle_Project_Options",
      "label" => E::ts("Hidden Logo"),
      "name" => "twingle_project_has_hidden_logo",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "Boolean",
      "html_type" => "Radio",
      "is_active" => 1,
      "is_view" => FALSE,
      "weight" => 35,
      "help_post" => E::ts("Hide the Logo on the project page")
    ],
    "twingle_project_has_projecttarget_as_money" => [
      "custom_group_id" => "Twingle_Project_Options",
      "label" => E::ts("Target Format"),
      "name" => "twingle_project_has_projecttarget_as_money",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "Boolean",
      "html_type" => "Radio",
      "is_active" => 1,
      "is_view" => FALSE,
      "weight" => 36,
      "help_post" => E::ts("Format of the reached portion of the donation target"),
      "default_value" => "0"
    ],
    "twingle_project_has_donationtarget_textfield" => [
      "custom_group_id" => "Twingle_Project_Options",
      "label" => E::ts("Donation Purpose as Textfield"),
      "name" => "twingle_project_has_donationtarget_textfield",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "Boolean",
      "html_type" => "Radio",
      "is_active" => 1,
      "is_view" => FALSE,
      "weight" => 37,
      "help_post" => E::ts("Let donors enter their own donation purpose")
    ],
    "twingle_project_has_civi_crm_activated" => [
      "custom_group_id" => "Twingle_Project_Options",
      "label" => E::ts("Activate CiviCRM Support"),
      "name" => "twingle_project_has_civi_crm_activated",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "Boolean",
      "html_type" => "Radio",
      "is_active" => 1,
      "is_view" => FALSE,
      "weight" => 38,
      "help_post" => E::ts("Activate support for Twingle Extension (de.systopia.twingle)"),
      "default_value" => TRUE,
    ],
    "twingle_project_has_step_index" => [
      "custom_group_id" => "Twingle_Project_Options",
      "label" => E::ts("Show Step Index"),
      "name" => "twingle_project_has_step_index",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "Boolean",
      "html_type" => "Radio",
      "is_active" => TRUE,
      "is_view" => FALSE,
      "weight" => 39,
      "help_post" => E::ts("Show a step index during donation process")
    ],
    "twingle_project_languages" => [
      "custom_group_id" => "Twingle_Project_Options",
      "label" => E::ts("Languages"),
      "name" => "twingle_project_languages",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "String",
      "html_type" => "Multi-Select",
      "option_values" => [
        "de" => E::ts("German"),
        "en" => E::ts("English"),
        "fr" => E::ts("French"),
        "es" => E::ts("Spanish")
      ],
      "is_active" => TRUE,
      "is_view" => FALSE,
      "weight" => 43
    ],
    "twingle_project_has_buttons" => [
      "custom_group_id" => "Twingle_Project_Options",
      "label" => E::ts("Buttons"),
      "name" => "twingle_project_has_buttons",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "Boolean",
      "html_type" => "Radio",
      "is_active" => TRUE,
      "is_view" => FALSE,
      "weight" => 44,
      "help_post" => E::ts("Up to four buttons can be configured. If you leave the amount blank, the button will not be displayed.")
    ],
    "twingle_project_has_no_slider" => [
      "custom_group_id" => "Twingle_Project_Options",
      "label" => E::ts("Slider"),
      "name" => "twingle_project_has_no_slider",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "Boolean",
      "html_type" => "Radio",
      "is_active" => TRUE,
      "is_view" => FALSE,
      "weight" => 44,
      "help_post" => E::ts("Show a slider that allows the donor to choose the donation amount.")
    ],
    "twingle_project_button1" => [
      "custom_group_id" => "Twingle_Project_Options",
      "label" => E::ts("Button 1"),
      "name" => "twingle_project_button1",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "String",
      "html_type" => "Text",
      "text_length" => 10,
      "is_active" => TRUE,
      "is_view" => FALSE,
      "weight" => 44,
      "help_post" => E::ts("Amount to be displayed on Button 1")
    ],
    "twingle_project_button2" => [
      "custom_group_id" => "Twingle_Project_Options",
      "label" => E::ts("Button 2"),
      "name" => "twingle_project_button2",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "String",
      "html_type" => "Text",
      "text_length" => 10,
      "is_active" => TRUE,
      "is_view" => FALSE,
      "weight" => 44,
      "help_post" => E::ts("Amount to be displayed on Button 2")
    ],
    "twingle_project_button3" => [
      "custom_group_id" => "Twingle_Project_Options",
      "label" => E::ts("Button 3"),
      "name" => "twingle_project_button3",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "String",
      "html_type" => "Text",
      "text_length" => 10,
      "is_active" => TRUE,
      "is_view" => FALSE,
      "weight" => 44,
      "help_post" => E::ts("Amount to be displayed on Button 3")
    ],
    "twingle_project_button4" => [
      "custom_group_id" => "Twingle_Project_Options",
      "label" => E::ts("Button 4"),
      "name" => "twingle_project_button4",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "String",
      "html_type" => "Text",
      "text_length" => 10,
      "is_active" => TRUE,
      "is_view" => FALSE,
      "weight" => 44,
      "help_post" => E::ts("Amount to be displayed on Button 4")
    ],
    "twingle_project_has_newsletter_namerequest" => [
      "custom_group_id" => "Twingle_Project_Options",
      "label" => E::ts("Newsletter Name Requested"),
      "name" => "twingle_project_has_newsletter_namerequest",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "Boolean",
      "html_type" => "Radio",
      "is_active" => TRUE,
      "is_view" => FALSE,
      "weight" => 44,
      "help_post" => E::ts("Must a donor give his name for newsletter sign-up?")
    ],
    "twingle_project_has_show_donator_data" => [
      "custom_group_id" => "Twingle_Project_Options",
      "label" => E::ts("Show List of Donations"),
      "name" => "twingle_project_has_show_donator_data",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "Boolean",
      "html_type" => "Radio",
      "is_active" => TRUE,
      "is_view" => FALSE,
      "weight" => 44,
      "help_post" => E::ts("Display a list of public donations")
    ],
    "twingle_project_payment_methods" => [
      "custom_group_id" => "Twingle_Project_Payment_Methods",
      "label" => E::ts("Payment Methods"),
      "name" => "twingle_project_payment_methods",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "String",
      "html_type" => "Multi-Select",
      "option_values" => [
        "has_paypal" => E::ts("PayPal"),
        "has_banktransfer" => E::ts("Banktransfer"),
        "has_debit" => E::ts("Debit"),
        "has_sofortueberweisung" => E::ts("Sofortüberweisung")
      ],
      "is_active" => TRUE,
      "is_view" => FALSE,
      "weight" => 45,
      "help_post" => E::ts("Chose which payment methods should be available. NOTE: You might have to activate them first in the Twingle-Manager configuration.")
    ],
    "twingle_project_payment_methods_recurring" => [
      "custom_group_id" => "Twingle_Project_Payment_Methods",
      "label" => E::ts("Recurring Payment Methods"),
      "name" => "twingle_project_payment_methods_recurring",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "String",
      "html_type" => "Multi-Select",
      "option_values" => [
        "has_paypal_recurring" => E::ts("PayPal"),
        "has_debit_recurring" => E::ts("Debit")
      ],
      "is_active" => TRUE,
      "is_view" => FALSE,
      "weight" => 45,
      "help_post" => E::ts("Display a list of public donations")
    ],
    "twingle_event_id" => [
      "custom_group_id" => "Twingle_Event_Information",
      "label" => E::ts("Twingle Event ID"),
      "name" => "twingle_event_id",
      "is_required" => TRUE,
      "is_searchable" => TRUE,
      "data_type" => "String",
      "html_type" => "Text",
      "text_length" => 16,
      "is_active" => TRUE,
      "is_view" => TRUE,
      "weight" => 1
    ],
    "twingle_event_project_id" => [
      "custom_group_id" => "Twingle_Event_Information",
      "label" => E::ts("Twingle Project ID"),
      "name" => "twingle_event_project_id",
      "is_required" => FALSE,
      "is_searchable" => TRUE,
      "data_type" => "String",
      "html_type" => "Text",
      "text_length" => 16,
      "is_active" => TRUE,
      "is_view" => TRUE,
      "weight" => 2
    ],
    "twingle_event_identifier" => [
      "custom_group_id" => "Twingle_Event_Information",
      "label" => E::ts("Identifier"),
      "name" => "twingle_event_identifier",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "String",
      "html_type" => "Text",
      "text_length" => 16,
      "is_active" => TRUE,
      "is_view" => TRUE,
      "weight" => 3
    ],
    "twingle_event_contact" => [
      "custom_group_id" => "Twingle_Event_Information",
      "label" => E::ts("Initiator"),
      "name" => "twingle_event_contact",
      "is_required" => FALSE,
      "is_searchable" => TRUE,
      "data_type" => "ContactReference",
      "html_type" => "Autocomplete-Select",
      "is_active" => TRUE,
      "is_view" => FALSE,
      "weight" => 5
    ],
    "twingle_event_user_email" => [
      "custom_group_id" => "Twingle_Event_Information",
      "label" => E::ts("Initiator Email"),
      "name" => "twingle_event_user_email",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "String",
      "html_type" => "Text",
      "text_length" => 128,
      "is_active" => TRUE,
      "is_view" => TRUE,
      "weight" => 6
    ],
    "twingle_event_is_public" => [
      "custom_group_id" => "Twingle_Event_Information",
      "label" => E::ts("Is public"),
      "name" => "twingle_event_is_public",
      "is_required" => FALSE,
      "is_searchable" => TRUE,
      "data_type" => "Boolean",
      "html_type" => "Radio",
      "is_active" => TRUE,
      "is_view" => TRUE,
      "weight" => 7
    ],
    "twingle_event_deleted" => [
      "custom_group_id" => "Twingle_Event_Information",
      "label" => E::ts("Deleted"),
      "name" => "twingle_event_deleted",
      "is_required" => FALSE,
      "is_searchable" => TRUE,
      "data_type" => "Boolean",
      "html_type" => "Radio",
      "is_active" => TRUE,
      "is_view" => TRUE,
      "weight" => 8
    ],
    "twingle_event_confirmed_at" => [
      "custom_group_id" => "Twingle_Event_Information",
      "label" => E::ts("Confirmed At"),
      "name" => "twingle_event_confirmed_at",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "String",
      "html_type" => "Text",
      "text_length" => 64,
      "is_active" => TRUE,
      "is_view" => TRUE,
      "weight" => 9
    ],
    "twingle_event_created_at" => [
      "custom_group_id" => "Twingle_Event_Information",
      "label" => E::ts("Created At"),
      "name" => "twingle_event_created_at",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "String",
      "html_type" => "Text",
      "text_length" => 64,
      "is_active" => TRUE,
      "is_view" => TRUE,
      "weight" => 10
    ],
    "twingle_event_creation_url" => [
      "custom_group_id" => "Twingle_Event_Information",
      "label" => E::ts("Creation URL"),
      "name" => "twingle_event_creation_url",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "String",
      "html_type" => "Text",
      "text_length" => 256,
      "is_active" => TRUE,
      "is_view" => TRUE,
      "weight" => 11
    ],
    "twingle_event_url_internal" => [
      "custom_group_id" => "Twingle_Event_Information",
      "label" => E::ts("Internal URL"),
      "name" => "twingle_event_url_internal",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "String",
      "html_type" => "Text",
      "text_length" => 256,
      "is_active" => TRUE,
      "is_view" => TRUE,
      "weight" => 12
    ],
    "twingle_event_url_external" => [
      "custom_group_id" => "Twingle_Event_Information",
      "label" => E::ts("External URL"),
      "name" => "twingle_event_url_external",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "String",
      "html_type" => "Text",
      "text_length" => 256,
      "is_active" => TRUE,
      "is_view" => TRUE,
      "weight" => 13
    ],
    "twingle_event_url_edit_internal" => [
      "custom_group_id" => "Twingle_Event_Information",
      "label" => E::ts("Edit Internal URL"),
      "name" => "twingle_event_url_edit_internal",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "String",
      "html_type" => "Text",
      "text_length" => 256,
      "is_active" => TRUE,
      "is_view" => TRUE,
      "weight" => 14
    ],
    "twingle_event_url_edit_external" => [
      "custom_group_id" => "Twingle_Event_Information",
      "label" => E::ts("Edit External URL"),
      "name" => "twingle_event_url_edit_external",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "String",
      "html_type" => "Text",
      "text_length" => 256,
      "is_active" => TRUE,
      "is_view" => TRUE,
      "weight" => 15
    ],
    "twingle_campaign_parent_project_id" => [
      "custom_group_id" => "Twingle_Campaign_Information",
      "label" => E::ts("Parent TwingleProject ID"),
      "name" => "twingle_campaign_parent_project_id",
      "is_required" => FALSE,
      "is_searchable" => TRUE,
      "data_type" => "String",
      "html_type" => "Text",
      "text_length" => 16,
      "is_active" => TRUE,
      "is_view" => TRUE,
      "weight" => 1
    ],
    "twingle_campaign_cid" => [
      "custom_group_id" => "Twingle_Campaign_Information",
      "label" => E::ts("CID"),
      "name" => "twingle_campaign_cid",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "Memo",
      "html_type" => "Text",
      "text_length" => 32,
      "is_active" => TRUE,
      "is_view" => TRUE,
      "weight" => 2
    ],
    "twingle_campaign_url" => [
      "custom_group_id" => "Twingle_Campaign_Information",
      "label" => E::ts("URL"),
      "name" => "twingle_campaign_url",
      "is_required" => FALSE,
      "is_searchable" => FALSE,
      "data_type" => "Memo",
      "html_type" => "TextArea",
      "text_length" => 600,
      "is_active" => TRUE,
      "is_view" => TRUE,
      "weight" => 3
    ]
  ]
];

